TileSet

Enum TileSet 

pub enum TileSet {
Show 16 variants Contours, Countries, Hillshading, Land, Landcover, MaptilerPlanet, MaptilerPlanetLite, OpenMapTiles, OpenMapTilesWGS84, Outdoor, Satellite, SatelliteMediumRes2016, SatelliteMediumRes2018, Terrain3D, TerrainRGB, Custom { endpoint: &'static str, extension: &'static str, },
}
The different types of tilesets that Maptiler Cloud supports

Variants



Contours

A contour map of the world Bytes returned will be a .pbf file



Countries

A (beta) map of the countries of the world Bytes returned will be a .pbf file



Hillshading

Shows hills as a transparent shaded relief Bytes returned will be a .png file



Land

A map of land vs. not land Bytes returned will be a .pbf file



Landcover

Land cover which stores what kinds of plants grow in specific areas Bytes returned will be a .pbf file



MaptilerPlanet

General purpose map format Bytes returned will be a .pbf file



MaptilerPlanetLite

Like MaptilerPlanet, but with extra data in only upper-level zooms Bytes returned will be a .pbf file



OpenMapTiles

OpenMapTiles format Bytes returned will be a .pbf file



OpenMapTilesWGS84

Same as OpenMapTiles, but in the WGS84 format Bytes returned will be a .pbf file



Outdoor

Maps for outdoor life like hiking, cycling, etc. Bytes returned will be a .pbf file



Satellite

Satellite images Bytes returned will be a .jpg file



SatelliteMediumRes2016

Satellite images but medium resolution from 2016 Bytes returned will be a .jpg file



SatelliteMediumRes2018

Satellite images but medium resolution from 2018 Bytes returned will be a .jpg file



Terrain3D

Contains terrain elevation data encoded into vector TIN polygons Bytes returned will be a quantized mesh file



TerrainRGB

Contains terrain elevation data encoded into RGB color model height = -10000 + ((R * 256 * 256 + G * 256 + B) * 0.1) Bytes returned will be a .png file



Custom

Specify your own custom TileSet

Fields

endpoint: &'static str

The Maptiler Cloud tile endpoint, for satellite imagery: “satellite”

extension: &'static str

The file extension that this endpoint returns, ex: “png”

Implementations

Source

impl TileSet

pub fn endpoint(&self) -> &'static str

Returns the endpoint that this tileset requires on the API request

For the satellite data tileset, the endpoint would be “satellite”

pub fn max_zoom(&self) -> u32

Returns the maximum zoom level that this tileset supports

The custom tileset variant has a maximum of 20 here, but it may be lower than that. Take care when using a custom tileset variant.

pub fn min_zoom(&self) -> u32

Returns the minimum zoom level that this tileset supports

The custom tileset variant has a minimum of 0 here, but it may be higher than that. Take care when using a custom tileset variant.

pub fn file_extension(&self) -> &'static str

Returns the file extension that this tileset returns as a static &str

Example outputs are: “png”, “jpg”, “pbf”